@@ -6,6 +6,7 @@ use warnings;
 
 use base 'WWW::Jawbone::Up::JSON';
 
-__PACKAGE__->add_accessors(qw(distance active_time aerobic calories steps time speed));
+__PACKAGE__->add_accessors(
+  qw(distance active_time aerobic calories steps time speed));
 
 1;
